@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  * 
- * $Id: actions.c 5314 2008-03-19 20:34:35Z charles $
+ * $Id: actions.c 5882 2008-05-21 17:27:36Z charles $
  */
 
 #include <string.h>
@@ -47,8 +47,9 @@ static GtkRadioActionEntry sort_radio_entries[] =
   { "sort-by-activity",   NULL, N_("Sort by _Activity"),   NULL, NULL, 0 },
   { "sort-by-name",       NULL, N_("Sort by _Name"),       NULL, NULL, 1 },
   { "sort-by-progress",   NULL, N_("Sort by _Progress"),   NULL, NULL, 2 },
-  { "sort-by-state",      NULL, N_("Sort by _State"),      NULL, NULL, 3 },
-  { "sort-by-tracker",    NULL, N_("Sort by _Tracker"),    NULL, NULL, 4 }
+  { "sort-by-ratio",      NULL, N_("Sort by _Ratio"),      NULL, NULL, 3 },
+  { "sort-by-state",      NULL, N_("Sort by _State"),      NULL, NULL, 4 },
+  { "sort-by-tracker",    NULL, N_("Sort by _Tracker"),    NULL, NULL, 5 }
 };
 
 static void
@@ -99,17 +100,17 @@ static GtkActionEntry entries[] =
   { "sort-menu", NULL, N_("_Sort Torrents By"), NULL, NULL, NULL },
   { "edit-menu", NULL, N_("_Edit"), NULL, NULL, NULL },
   { "help-menu", NULL, N_("_Help"), NULL, NULL, NULL },
-  { "open-torrent-toolbar", GTK_STOCK_OPEN, NULL, NULL, N_("Open a torrent"), G_CALLBACK(action_cb) },
-  { "open-torrent-menu", GTK_STOCK_OPEN, N_("_Open..."), NULL, N_("Open a torrent"), G_CALLBACK(action_cb) },
+  { "add-torrent-toolbar", GTK_STOCK_ADD, NULL, NULL, N_("Add a torrent"), G_CALLBACK(action_cb) },
+  { "add-torrent-menu", GTK_STOCK_ADD, N_("_Add..."), "<control>D", N_("Add a torrent"), G_CALLBACK(action_cb) },
   { "start-torrent", GTK_STOCK_MEDIA_PLAY,
-    N_("_Start"), "<control>S", NULL, G_CALLBACK(action_cb) },
+    N_("_Start"), "<control>S", N_("Start torrent"), G_CALLBACK(action_cb) },
   { "show-stats", NULL, N_("_Statistics"), NULL, NULL, G_CALLBACK(action_cb) },
   { "verify-torrent", NULL,
     N_("_Verify Local Data"), NULL, NULL, G_CALLBACK(action_cb) },
   { "pause-torrent", GTK_STOCK_MEDIA_PAUSE,
-    N_("_Pause"), "<control>P", NULL, G_CALLBACK(action_cb) },
-  { "remove-torrent", GTK_STOCK_REMOVE, NULL, "Delete", NULL, G_CALLBACK(action_cb) },
-  { "delete-torrent", GTK_STOCK_DELETE, N_("_Delete Files and Remove"), "<control>Delete", NULL, G_CALLBACK(action_cb) },
+    N_("_Pause"), "<control>P", N_("Pause torrent"), G_CALLBACK(action_cb) },
+  { "remove-torrent", GTK_STOCK_REMOVE, NULL, "Delete", N_("Remove torrent"), G_CALLBACK(action_cb) },
+  { "delete-torrent", GTK_STOCK_DELETE, N_("_Delete Files and Remove"), "<shift>Delete", NULL, G_CALLBACK(action_cb) },
   { "new-torrent", GTK_STOCK_NEW, N_("_New..."), NULL,
     N_("Create a torrent"),
     G_CALLBACK(action_cb) },
@@ -123,8 +124,11 @@ static GtkActionEntry entries[] =
     N_("Dese_lect All"), "<shift><control>A", NULL, G_CALLBACK(action_cb) },
   { "edit-preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL, G_CALLBACK(action_cb) },
   { "show-torrent-details", GTK_STOCK_INFO,
-    N_("_Details"), "<alt>Return", NULL, G_CALLBACK(action_cb) },
+    N_("_Details"), "<alt>Return", N_("Torrent details"), G_CALLBACK(action_cb) },
+  { "open-torrent-folder", GTK_STOCK_OPEN,
+    N_("_Open Folder"), NULL, NULL, G_CALLBACK(action_cb) },
   { "show-about-dialog", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK(action_cb) },
+  { "help", GTK_STOCK_HELP, NULL, NULL, NULL, G_CALLBACK(action_cb) },
   { "update-tracker", GTK_STOCK_NETWORK,
     N_("Ask Tracker for _More Peers"), NULL, NULL, G_CALLBACK(action_cb) }
 };
