@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  * 
- * $Id: tr-prefs.c 5782 2008-05-09 03:20:34Z charles $
+ * $Id: tr-prefs.c 6182 2008-06-13 21:12:49Z charles $
  */
 
 #include <stdlib.h> /* free() */
@@ -103,9 +103,13 @@ tr_prefs_init_global( void )
 static void
 response_cb( GtkDialog * dialog, int response, gpointer unused UNUSED )
 {
-    if( response == GTK_RESPONSE_HELP )
-        gtr_open_file( "http://www.transmissionbt.com/help/gtk/"
-                       SHORT_VERSION_STRING "/html/preferences.html" );
+    if( response == GTK_RESPONSE_HELP ) {
+        char * base = gtr_get_help_url( );
+        char * url = g_strdup_printf( "%s/html/preferences.html", base );
+        gtr_open_file( url );
+        g_free( url );
+        g_free( base );
+    }
 
     if( response == GTK_RESPONSE_CLOSE )
         gtk_widget_destroy( GTK_WIDGET(dialog) );
