@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: tr-window.c 5313 2008-03-19 20:07:27Z charles $
+ * $Id: tr-window.c 5673 2008-04-24 01:42:53Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -179,16 +179,6 @@ makeview( PrivateData * p, TrCore * core )
     return view;
 }
 
-static void
-realized_cb ( GtkWidget * wind, gpointer unused UNUSED )
-{
-    PrivateData * p = get_private_data( GTK_WINDOW( wind ) );
-    sizingmagic( GTK_WINDOW(wind),
-                 GTK_SCROLLED_WINDOW( p->scroll ),
-                 GTK_POLICY_NEVER,
-                 GTK_POLICY_AUTOMATIC );
-}
-
 static void
 prefsChanged( TrCore * core UNUSED, const char * key, gpointer wind )
 {
@@ -269,7 +259,7 @@ checkFilterText( filter_text_mode_t    filter_text_mode,
                  const tr_info       * torInfo,
                  const char          * text )
 {
-    int i;
+    tr_file_index_t i;
     int ret = 0;
     char * pch;
 
@@ -284,7 +274,7 @@ checkFilterText( filter_text_mode_t    filter_text_mode,
             break;
 
         case FILTER_TEXT_MODE_TRACKER:
-            pch = g_ascii_strdown( torInfo->primaryAddress, -1 );
+            pch = g_ascii_strdown( torInfo->trackers[0].announce, -1 );
             ret = !text || ( strstr( pch, text ) != NULL );
             g_free( pch );
             break;
@@ -301,27 +291,26 @@ checkFilterText( filter_text_mode_t    filter_text_mode,
 
 static int
 checkFilterMode( filter_mode_t       filter_mode,
-                 const tr_stat     * torStat )
+                 tr_torrent        * tor )
 {
     int ret = 0;
-    const int haveDown = torStat->peersSendingToUs > 0;
-    const int haveUp = torStat->peersGettingFromUs > 0;
 
     switch( filter_mode )
     {
-        case FILTER_MODE_ACTIVE:
-            ret = haveUp || haveDown;
-            break;
         case FILTER_MODE_DOWNLOADING:
-            ret = torStat->status == TR_STATUS_DOWNLOAD;
+            ret = tr_torrentGetStatus( tor ) == TR_STATUS_DOWNLOAD;
             break;
         case FILTER_MODE_SEEDING:
-            ret =    ( torStat->status == TR_STATUS_DONE )
-                  || ( torStat->status == TR_STATUS_SEED );
+            ret = tr_torrentGetStatus( tor ) == TR_STATUS_SEED;
             break;
         case FILTER_MODE_PAUSED:
-            ret = torStat->status == TR_STATUS_STOPPED;
+            ret = tr_torrentGetStatus( tor ) == TR_STATUS_STOPPED;
             break;
+        case FILTER_MODE_ACTIVE: {
+            const tr_stat * s = tr_torrentStatCached( tor );
+            ret = s->peersSendingToUs>0 || s->peersGettingFromUs>0;
+            break;
+        }
         default: /* all */
             ret = 1;
     }
@@ -338,7 +327,7 @@ is_row_visible( GtkTreeModel   * model,
     tr_torrent * tor;
     gtk_tree_model_get( model, iter, MC_TORRENT_RAW, &tor, -1 );
 
-    return checkFilterMode( p->filter_mode, tr_torrentStatCached( tor ) )
+    return checkFilterMode( p->filter_mode, tor )
         && checkFilterText( p->filter_text_mode, tr_torrentInfo( tor ), p->filter_text );
 }
 
@@ -427,6 +416,7 @@ tr_window_new( GtkUIManager * ui_manager, TrCore * core )
     char * pch;
     PrivateData * p;
     GtkWidget *vbox, *w, *self, *h, *c, *s, *image, *menu;
+    GtkWindow *win;
     GSList * l;
     GSList * toggles;
     const char * filter_names[FILTER_MODE_QTY] = {
@@ -453,11 +443,14 @@ tr_window_new( GtkUIManager * ui_manager, TrCore * core )
     /* make the window */
     self = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     g_object_set_data_full(G_OBJECT(self), PRIVATE_DATA_KEY, p, privateFree );
-    gtk_window_set_title( GTK_WINDOW( self ), g_get_application_name());
-    gtk_window_set_role( GTK_WINDOW( self ), "tr-main" );
-    gtk_window_add_accel_group (GTK_WINDOW(self),
-                                gtk_ui_manager_get_accel_group (ui_manager));
-    g_signal_connect( self, "realize", G_CALLBACK(realized_cb), NULL);
+    win = GTK_WINDOW( self );
+    gtk_window_set_title( win, g_get_application_name());
+    gtk_window_set_role( win, "tr-main" );
+    gtk_window_set_default_size( win, pref_int_get( PREF_KEY_MAIN_WINDOW_WIDTH ),
+                                      pref_int_get( PREF_KEY_MAIN_WINDOW_HEIGHT ) );
+    gtk_window_move( win, pref_int_get( PREF_KEY_MAIN_WINDOW_X ),
+                          pref_int_get( PREF_KEY_MAIN_WINDOW_Y ) );
+    gtk_window_add_accel_group( win, gtk_ui_manager_get_accel_group( ui_manager ) );
 
     /* window's main container */
     vbox = gtk_vbox_new (FALSE, 0);
@@ -565,6 +558,7 @@ tr_window_new( GtkUIManager * ui_manager, TrCore * core )
     /* workarea */
     p->view = makeview( p, core );
     w = p->scroll = gtk_scrolled_window_new( NULL, NULL );
+    gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW(w), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC );
     gtk_container_add( GTK_CONTAINER(w), p->view );
     gtk_box_pack_start_defaults( GTK_BOX(vbox), w );
     gtk_container_set_focus_child( GTK_CONTAINER( vbox ), w );
