@@ -2,14 +2,16 @@ const char * fallback_ui_file =
 "<ui>\n"
 "  <menubar name='main-window-menu'>\n"
 "    <menu action='torrent-menu'>\n"
-"      <menuitem action='open-torrent-menu'/>\n"
+"      <menuitem action='add-torrent-menu'/>\n"
 "      <menuitem action='new-torrent'/>\n"
 "      <separator/>\n"
+"      <menuitem action='show-torrent-details'/>\n"
+"      <menuitem action='open-torrent-folder'/>\n"
+"      <separator/>\n"
 "      <menuitem action='start-torrent'/>\n"
 "      <menuitem action='update-tracker'/>\n"
 "      <menuitem action='pause-torrent'/>\n"
 "      <menuitem action='verify-torrent'/>\n"
-"      <menuitem action='show-torrent-details'/>\n"
 "      <menuitem action='remove-torrent'/>\n"
 "      <menuitem action='delete-torrent'/>\n"
 "      <separator/>\n"
@@ -32,6 +34,7 @@ const char * fallback_ui_file =
 "      <menuitem action='sort-by-activity'/>\n"
 "      <menuitem action='sort-by-name'/>\n"
 "      <menuitem action='sort-by-progress'/>\n"
+"      <menuitem action='sort-by-ratio'/>\n"
 "      <menuitem action='sort-by-state'/>\n"
 "      <menuitem action='sort-by-tracker'/>\n"
 "      <separator/>\n"
@@ -41,12 +44,13 @@ const char * fallback_ui_file =
 "      <menuitem action='toggle-message-log'/>\n"
 "      <menuitem action='show-stats'/>\n"
 "      <separator/>\n"
+"      <menuitem action='help'/>\n"
 "      <menuitem action='show-about-dialog'/>\n"
 "    </menu>\n"
 "  </menubar>\n"
 "\n"
 "  <toolbar name='main-window-toolbar'>\n"
-"    <toolitem action='open-torrent-toolbar'/>\n"
+"    <toolitem action='add-torrent-toolbar'/>\n"
 "    <toolitem action='start-torrent'/>\n"
 "    <toolitem action='pause-torrent'/>\n"
 "    <toolitem action='remove-torrent'/>\n"
@@ -56,6 +60,7 @@ const char * fallback_ui_file =
 "\n"
 "  <popup name='main-window-popup'>\n"
 "    <menuitem action='show-torrent-details'/>\n"
+"    <menuitem action='open-torrent-folder'/>\n"
 "    <separator/>\n"
 "    <menuitem action='start-torrent'/>\n"
 "    <menuitem action='pause-torrent'/>\n"
@@ -67,7 +72,7 @@ const char * fallback_ui_file =
 "  </popup>\n"
 "\n"
 "  <popup name='icon-popup'>\n"
-"    <menuitem action='open-torrent-menu'/>\n"
+"    <menuitem action='add-torrent-menu'/>\n"
 "    <separator/>\n"
 "    <menuitem action='toggle-main-window'/>\n"
 "    <menuitem action='toggle-message-log'/>\n"
