@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: torrent.h 5204 2008-03-06 13:24:44Z charles $
+ * $Id: torrent.h 5748 2008-05-05 19:51:53Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -26,10 +26,10 @@
 #define TR_TORRENT_H 1
 
 /* just like tr_torrentSetFileDLs but doesn't trigger a fastresume save */
-void tr_torrentInitFileDLs( tr_torrent   * tor,
-                            int          * files,
-                            int            fileCount,
-                            int            do_download );
+void tr_torrentInitFileDLs( tr_torrent       * tor,
+                            tr_file_index_t  * files,
+                            tr_file_index_t    fileCount,
+                            int                do_download );
 
 int tr_torrentIsPrivate( const tr_torrent * );
 
@@ -37,7 +37,9 @@ void tr_torrentRecheckCompleteness( tr_torrent * );
 
 void tr_torrentResetTransferStats( tr_torrent * );
 
-void tr_torrentSetHasPiece( tr_torrent * tor, int pieceIndex, int has );
+void tr_torrentSetHasPiece( tr_torrent       * tor,
+                            tr_piece_index_t   pieceIndex,
+                            int                has );
 
 void tr_torrentLock    ( const tr_torrent * );
 void tr_torrentUnlock  ( const tr_torrent * );
@@ -73,27 +75,36 @@ int tr_torrentAllowsPex( const tr_torrent * );
     ( ((block)==((tor)->blockCount-1)) ? (tor)->lastBlockSize : (tor)->blockSize )
 
 #define tr_block(a,b) _tr_block(tor,a,b)
-int _tr_block( const tr_torrent * tor, int index, int begin );
+tr_block_index_t _tr_block( const tr_torrent * tor,
+                            tr_piece_index_t   index,
+                            uint32_t           offset );
 
 int tr_torrentReqIsValid( const tr_torrent * tor,
-                          uint32_t           index,
+                          tr_piece_index_t   index,
                           uint32_t           offset,
                           uint32_t           length );
 
-uint64_t tr_pieceOffset( const tr_torrent * tor, int index, int begin, int length );
+uint64_t tr_pieceOffset( const tr_torrent * tor,
+                         tr_piece_index_t   index,
+                         uint32_t           offset,
+                         uint32_t           length );
 
-void tr_torrentInitFilePriority( tr_torrent   * tor,
-                                 int            fileIndex,
-                                 tr_priority_t  priority );
+void tr_torrentInitFilePriority( tr_torrent       * tor,
+                                 tr_file_index_t    fileIndex,
+                                 tr_priority_t      priority );
 
 
 int  tr_torrentCountUncheckedPieces( const tr_torrent * );
-int  tr_torrentIsPieceChecked      ( const tr_torrent *, int piece );
-int  tr_torrentIsFileChecked       ( const tr_torrent *, int file );
-void tr_torrentSetPieceChecked     ( tr_torrent *, int piece, int isChecked );
-void tr_torrentSetFileChecked      ( tr_torrent *, int file, int isChecked );
+int  tr_torrentIsPieceChecked      ( const tr_torrent *, tr_piece_index_t piece );
+int  tr_torrentIsFileChecked       ( const tr_torrent *, tr_file_index_t file );
+void tr_torrentSetPieceChecked     ( tr_torrent *, tr_piece_index_t piece, int isChecked );
+void tr_torrentSetFileChecked      ( tr_torrent *, tr_file_index_t file, int isChecked );
 void tr_torrentUncheck             ( tr_torrent * );
 
+int tr_torrentPromoteTracker       ( tr_torrent *, int trackerIndex );
+
+time_t* tr_torrentGetMTimes        ( const tr_torrent *, int * setmeCount );
+
 typedef enum
 {
    TR_VERIFY_NONE,
@@ -104,14 +115,14 @@ tr_verify_state;
 
 struct tr_torrent
 {
-    tr_handle                 * handle;
-    tr_info                     info;
+    tr_handle                * handle;
+    tr_info                    info;
 
-    tr_speedlimit               uploadLimitMode;
-    tr_speedlimit               downloadLimitMode;
-    struct tr_ratecontrol     * upload;
-    struct tr_ratecontrol     * download;
-    struct tr_ratecontrol     * swarmspeed;
+    tr_speedlimit              uploadLimitMode;
+    tr_speedlimit              downloadLimitMode;
+    struct tr_ratecontrol    * upload;
+    struct tr_ratecontrol    * download;
+    struct tr_ratecontrol    * swarmspeed;
 
     int                        error;
     char                       errorString[128];
@@ -122,14 +133,14 @@ struct tr_torrent
     char                     * destination;
     
     /* How many bytes we ask for per request */
-    int                        blockSize;
-    int                        blockCount;
+    uint32_t                   blockSize;
+    tr_block_index_t           blockCount;
 
-    int                        lastBlockSize;
-    int                        lastPieceSize;
+    uint32_t                   lastBlockSize;
+    uint32_t                   lastPieceSize;
 
-    int                        blockCountInPiece;
-    int                        blockCountInLastPiece;
+    uint32_t                   blockCountInPiece;
+    uint32_t                   blockCountInLastPiece;
     
     struct tr_completion     * completion;
 
@@ -156,16 +167,15 @@ struct tr_torrent
     tr_torrent_active_func   * active_func;
     void                     * active_func_user_data;
 
-    unsigned int               statCur : 1;
     unsigned int               isRunning : 1;
     unsigned int               isDeleting : 1;
 
     uint16_t                   maxConnectedPeers;
 
-    tr_verify_state           verifyState;
+    tr_verify_state            verifyState;
 
     time_t                     lastStatTime;
-    tr_stat                    stats[2];
+    tr_stat                    stats;
 
     tr_torrent               * next;
 };
