@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: tracker.h 5086 2008-02-21 07:29:39Z charles $
+ * $Id: tracker.h 5647 2008-04-19 15:07:59Z charles $
  */
 
 #ifndef _TR_TRACKER_H_
@@ -54,8 +54,9 @@ typedef struct
     const char * text;
 
     /* for TR_TRACKER_PEERS */
-    const uint8_t * peerCompact;
-    int peerCount;
+    const uint8_t * compact;
+    int compactLen;
+    int allAreSeeds;
 }
 tr_tracker_event;
 
