@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: Torrent.h 5325 2008-03-21 21:07:31Z livings124 $
+ * $Id: Torrent.h 5678 2008-04-24 06:35:21Z livings124 $
  *
  * Copyright (c) 2006-2008 Transmission authors and contributors
  *
@@ -36,21 +36,20 @@ typedef enum
 
 @interface Torrent : NSObject
 {
-    tr_handle * fLib;
     tr_torrent * fHandle;
     const tr_info * fInfo;
     const tr_stat * fStat;
     
     int fID;
     
-    BOOL         fResumeOnWake;
-    NSDate       * fDateAdded, * fDateCompleted, * fDateActivity;
+    BOOL fResumeOnWake;
+    NSDate * fDateAdded, * fDateCompleted, * fDateActivity;
     
-    BOOL        fUseIncompleteFolder;
-    NSString    * fDownloadFolder, * fIncompleteFolder;
+    BOOL fUseIncompleteFolder;
+    NSString * fDownloadFolder, * fIncompleteFolder;
     
-    BOOL        fPublicTorrent;
-    NSString    * fPublicTorrentLocation;
+    BOOL fPublicTorrent;
+    NSString * fPublicTorrentLocation;
 	
     NSUserDefaults * fDefaults;
 
@@ -140,7 +139,6 @@ typedef enum
 - (uint64_t) size;
 - (uint64_t) sizeLeft;
 
-- (NSString *) trackerAddress;
 - (NSString *) trackerAddressAnnounce;
 - (NSDate *) lastAnnounceTime;
 - (int) nextAnnounceTime;
@@ -254,7 +252,6 @@ typedef enum
 - (NSNumber *) stateSortKey;
 
 - (int) torrentID;
-- (const tr_info *) torrentInfo;
-- (const tr_stat *) torrentStat;
+- (tr_torrent *) torrentStruct;
 
 @end
